from odoo import _, api, fields, models

class CatalogPricelistReport(models.TransientModel):
    _name = "catalog.pricelist.report.wizard"
    _description = 'Catalog Pricelist Report'

    @api.onchange('pricelist_id')
    def _onchange_pricelist_id(self):
        if self.pricelist_id:
            pricelist_item_records = self.env['product.pricelist.item'].search([('pricelist_id', '=', self.pricelist_id.id)])
            min_quantities = sorted([record.min_quantity for record in pricelist_item_records])
            self.qty_1 = min_quantities[0] if len(min_quantities) >= 1 else 0
            self.qty_2 = min_quantities[1] if len(min_quantities) >= 2 else 0
            self.qty_3 = min_quantities[2] if len(min_quantities) >= 3 else 0
    
    @api.model
    def _lang_get(self):
        return self.env["res.lang"].get_installed()

    pricelist_id = fields.Many2one('product.pricelist')
    language_id = fields.Selection(_lang_get, string="Language", default=lambda self: self.env.user.lang)
    custom_title = fields.Char(string="Custom Title")
    qty_1 = fields.Integer(default=lambda self: self.qty_1)
    qty_2 = fields.Integer(default=lambda self: self.qty_2)
    qty_3 = fields.Integer(default=lambda self: self.qty_3)
    print_images = fields.Boolean(string="Print Image", default=True)
    print_attributes = fields.Boolean(string="Print Attributes", default=False)
    attribute_bg_color = fields.Char(string="Attribute background Color")

    # barcode_print = fields.Boolean(string="Print Barcode", default=False)
    # barcode_type = fields.Selection([('codabar', 'Codabar'),
    #                                  ('codell', 'Code11'),
    #                                  ('code128', 'Code128'),
    #                                  ('ean13', 'EAN13'), ('ean8', 'EAN8'),
    #                                  ('extended39', 'Extended39'),
    #                                  ('extended93', 'Extended93'),
    #                                  ('fim', 'FIM'),
    #                                  ('i2of5', 'i2of5'),
    #                                  ('msi', 'MSI'),
    #                                  ('postnet', 'Postnet'),
    #                                  ('qr', 'QR'),
    #                                  ('standard39', 'Standard39'),
    #                                  ('standard93', 'Standard93'),
    #                                  ('usps_4stater', 'USPS_4Stater')],
    #                                 default="ean13", string="Barcode Type")
    # barcode_height = fields.Integer(string="Barcode Height", default='200')
    # barcode_width = fields.Integer(string="Barcode Width", default='50')
    
    available_quantity = fields.Boolean(string="Print Available Quantity")
    forecasted_quantity = fields.Boolean(string="Print Forecasted Quantity")
    image = fields.Binary(string='Add Logo In Report')

    pricelist_date = fields.Date('Pricelist Date', default=lambda self: fields.Date.context_today(self))
    valid_until = fields.Date('Expiration Date', default=lambda self: fields.Date.context_today(self))
    # print_brands = fields.Boolean(string="Print Brands", default = False)

    def print_report(self):
        active_ids = self.env.context.get('active_ids', [])
        data = self.read()[0]
        datas = {
            'ids': active_ids,
            'model': 'product.product',
            'form': data,
        }
        return self.env.ref(
            'dr_catalog_pricelist.action_catalog_report').report_action(
            [], data=datas)